@@ -16,7 +16,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef HA_MROONGA_HPP_
@@ -703,6 +703,7 @@ private:
   int ensure_normalizers_register();
   int ensure_database_create(const char *name);
   int ensure_database_open(const char *name);
+  int ensure_database_remove(const char *name);
   int wrapper_delete_table(const char *name, MRN_SHARE *tmp_share,
                            const char *table_name);
   int wrapper_delete_index(const char *name, MRN_SHARE *tmp_share,
@@ -710,7 +711,7 @@ private:
   int storage_delete_table(const char *name, MRN_SHARE *tmp_share,
                            const char *table_name);
   int wrapper_open(const char *name, int mode, uint test_if_locked);
-  int wrapper_open_indexes(const char *name, bool ignore_open_error);
+  int wrapper_open_indexes(const char *name);
   int storage_open(const char *name, int mode, uint test_if_locked);
   int open_table(const char *name);
   int storage_open_columns(void);
